import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';

class ArcPainter extends CustomPainter {
  ArcPainter(this._fraction, this.backgroundColor, this.progress, {this.strokeWidth = 4}) {
    _backgroundPaint.color = backgroundColor;
    _backgroundPaint.strokeWidth = strokeWidth;
    _backgroundPaint.strokeCap = StrokeCap.round;
    _backgroundPaint.style = PaintingStyle.stroke;

    _linePaint.strokeWidth = strokeWidth;
    _linePaint.strokeCap = StrokeCap.round;
    _linePaint.style = PaintingStyle.stroke;
  }

  final Paint _backgroundPaint = Paint();
  final Paint _linePaint = Paint();

  final double _fraction;
  final double strokeWidth;

  final Color backgroundColor;
  final Map<double, Color> progress;

  @override
  void paint(Canvas canvas, Size size) {
    final double offset = strokeWidth;
    final Rect rect = Rect.fromLTWH(offset, offset, size.width - (offset * 2), (size.height - (offset * 2)) * 2);

    canvas.drawArc(rect, -pi, pi, false, _backgroundPaint);

    progress.forEach((ratio, color) {
      _linePaint.color = color;
      if (ratio != 0) {
        canvas.drawArc(rect, -pi, pi * ratio * _fraction, false, _linePaint);
      }
    });
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return true;
  }
}
