import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:ampos_ui_library/chart/progress_bar/arc_painter.dart';
import 'package:ampos_ui_library/chart/progress_bar/linear_painter.dart';
import 'package:ampos_ui_library/chart/progress_bar/progress_bar_type.dart';
import 'package:ampos_ui_library/chart/progress_bar/progress_item.dart';
import 'package:ampos_ui_library/style/ampos_colors.dart';

class MultipleValueProgressBar extends StatefulWidget {
  MultipleValueProgressBar(
      {Key key,
      @required this.width,
      @required this.height,
      this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
      this.values,
      this.maxValue = 100,
      this.backgroundColor = AmposColors.gainsboro,
      this.strokeWidth = 4,
      this.progressBarType = ProgressBarType.LINEAR})
      : super(key: key);

  final double width;
  final double height;
  final double strokeWidth;

  final EdgeInsets margin;
  final List<ProgressItem> values;

  final double maxValue;

  final Color backgroundColor;

  final ProgressBarType progressBarType;

  @override
  State<StatefulWidget> createState() => _MultipleValueProgressBar();
}

class _MultipleValueProgressBar extends State<MultipleValueProgressBar>
    with SingleTickerProviderStateMixin {
  Animation<double> animation;
  double _fraction = 0.0;

  @override
  void initState() {
    super.initState();
    final controller =
        AnimationController(duration: Duration(milliseconds: 500), vsync: this);

    animation = Tween(begin: 0.0, end: 1.0).animate(controller)
      ..addListener(() {
        setState(() {
          _fraction = animation.value;
        });
      });

    controller.forward();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: widget.width,
      height: widget.height,
      margin: widget.margin,
      child: CustomPaint(
        painter: getPainter(
          widget.progressBarType,
          _fraction,
          widget.backgroundColor,
          _getProgressRatios(widget.maxValue, widget.values),
          widget.strokeWidth,
        ),
      ),
    );
  }

  Map<double, Color> _getProgressRatios(
      double maxValue, List<ProgressItem> values) {
    final entries = values.map((item) {
      final ratio = (item.value >= maxValue) ? 1.0 : (item.value / maxValue);
      return MapEntry(ratio, item.color);
    });
    return Map.fromEntries(entries);
  }

  CustomPainter getPainter(ProgressBarType type, double fraction,
      Color backgroundColor, Map<double, Color> progress, double strokeWidth) {
    switch (type) {
      case ProgressBarType.ARC:
        return ArcPainter(fraction, backgroundColor, progress,
            strokeWidth: strokeWidth);
      default:
        return LinearPainter(fraction, backgroundColor, progress,
            strokeWidth: strokeWidth);
    }
  }
}
