import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

part 'two_button_dialog_view_model.dart';

enum DialogAction { CANCEL, CONFIRM }

class TwoButtonDialog {
  TwoButtonDialog(this._context, this._viewModel)
      : assert(_context != null),
        assert(_viewModel != null) {
    _viewModel._onShow = show;
  }

  BuildContext _context;
  TwoButtonDialogViewModel _viewModel;

  Widget _cupertinoDialog() {
    return CupertinoAlertDialog(
      title: Text(_viewModel.title),
      content: Text(_viewModel.content),
      actions: <Widget>[
        CupertinoDialogAction(
          child: Text(_viewModel.cancelText),
          onPressed: () => Navigator.of(_context).pop(DialogAction.CANCEL),
        ),
        CupertinoDialogAction(
          isDefaultAction: true,
          child: Text(_viewModel.confirmText),
          onPressed: () => Navigator.of(_context).pop(DialogAction.CONFIRM),
        ),
      ],
    );
  }

  Widget _materialDialog() {
    return AlertDialog(
      title: _viewModel.title != null ? Text(_viewModel.title) : null,
      content: _viewModel.content != null ? Text(_viewModel.content) : null,
      actions: <Widget>[
        FlatButton(
          child: Text(_viewModel.cancelText),
          onPressed: () => Navigator.of(_context).pop(DialogAction.CANCEL),
        ),
        FlatButton(
          child: Text(_viewModel.confirmText),
          onPressed: () => Navigator.of(_context).pop(DialogAction.CONFIRM),
        ),
      ],
    );
  }

  Future<void> show() async {
    final DialogAction action = await showDialog<DialogAction>(
      context: _context,
      builder: (_) {
        if (Platform.isIOS) {
          return _cupertinoDialog();
        }
        return _materialDialog();
      },
    );

    switch (action) {
      case DialogAction.CONFIRM:
        if (_viewModel.onConfirm != null) {
          _viewModel.onConfirm();
        }
        break;
      case DialogAction.CANCEL:
        if (_viewModel.onCancel != null) {
          _viewModel.onCancel();
        }
        break;
    }
  }
}
