import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class ImageCard extends StatelessWidget {
  ImageCard({
    @required this.text,
    @required this.image,
    this.ratio = 0.95,
    this.onTap,
  }) : assert(ratio != null);

  final Image image;
  final String text;
  final GestureTapCallback onTap;
  final double ratio;

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: GestureDetector(
        onTap: onTap,
        child: Card(
          margin: EdgeInsets.symmetric(horizontal: 4),
          child: AspectRatio(
            aspectRatio: ratio,
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              mainAxisSize: MainAxisSize.max,
              children: <Widget>[_buildText(), _buildImage()],
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildText() {
    return Container(
      height: 48,
      alignment: Alignment.topLeft,
      padding: EdgeInsets.only(left: 8, right: 8, top: 8),
      child: Text(
        text,
        textAlign: TextAlign.start,
        overflow: TextOverflow.ellipsis,
        maxLines: 2,
        style: TextStyle(fontWeight: FontWeight.bold),
      ),
    );
  }

  Widget _buildImage() {
    return Flexible(
      child: Container(
        padding: EdgeInsets.only(bottom: 8),
        alignment: Alignment.center,
        child: FractionallySizedBox(
          widthFactor: 0.5,
          child: image,
        ),
      ),
    );
  }
}
