import 'package:flutter/widgets.dart';

class PercentageOpacity extends StatelessWidget {
  PercentageOpacity({
    @required this.percentage,
    this.startHidePercentage = 1,
    this.fullHidePercentage = 0,
    this.child,
  })  : assert(percentage != null && percentage >= 0.0 && percentage <= 1.0),
        assert(startHidePercentage != null &&
            startHidePercentage >= 0.0 &&
            startHidePercentage <= 1.0),
        assert(fullHidePercentage != null &&
            fullHidePercentage >= 0.0 &&
            fullHidePercentage <= 1.0);

  final num percentage;
  final double startHidePercentage;
  final double fullHidePercentage;
  final Widget child;

  @override
  Widget build(BuildContext context) {
    return Opacity(
      opacity: _calculateOpacity(),
      child: child,
    );
  }

  double _calculateOpacity() {
    if (startHidePercentage < fullHidePercentage) {
      if (percentage >= fullHidePercentage) {
        return 0;
      } else if (percentage > startHidePercentage) {
        return 1 -
            ((percentage - startHidePercentage) /
                (fullHidePercentage - startHidePercentage));
      } else {
        return 1;
      }
    } else {
      if (percentage >= startHidePercentage) {
        return 1;
      } else if (percentage > fullHidePercentage) {
        return (percentage - fullHidePercentage) /
            (startHidePercentage - fullHidePercentage);
      } else {
        return 0;
      }
    }
  }
}
