import 'package:ampos_ui_library/ampos_ui_library.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class ThumbnailCard extends StatelessWidget {
  ThumbnailCard({
    @required this.title,
    @required this.actionText,
    this.actionIcon,
    this.image,
    this.imageRatio = 4 / 3,
    this.onTap,
  })  : assert(actionText != null),
        assert(title != null),
        assert(imageRatio != null);

  final String title;
  final String actionText;
  final String actionIcon;
  final Image image;
  final double imageRatio;
  final GestureTapCallback onTap;

  @override
  Widget build(BuildContext context) {
    return Expanded(
      child: Card(
        clipBehavior: Clip.antiAlias,
        child: GestureDetector(
          onTap: () => onTap,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
              _buildImage(),
              _buildTitleText(),
              _buildActionItems(),
            ],
          ),
        ),
      ),
    );
  }

  Widget _buildImage() {
    return AspectRatio(
      aspectRatio: imageRatio,
      child: image,
    );
  }

  Widget _buildActionItems() {
    final List<Widget> actionWidgets = [];

    if (actionIcon != null) {
      actionWidgets.add(Container(
        child: Image.asset(
          actionIcon,
          fit: BoxFit.contain,
          height: 12,
          width: 12,
        ),
      ));
    }
    actionWidgets.add(
      TextWidget(
        actionText,
        color: AmposColors.outerSpace,
        fontSize: FontSize.extraSmall,
      ),
    );

    return Container(
      padding: EdgeInsets.only(bottom: 8, left: 8, right: 8),
      child: Row(children: actionWidgets),
    );
  }

  Widget _buildTitleText() {
    return Container(
      alignment: Alignment.topLeft,
      height: 48,
      padding: EdgeInsets.only(top: 8, left: 8, right: 8),
      child: TextWidget(
        title,
        maxLines: 2,
        textAlign: TextAlign.start,
        fontWeight: FontWeight.bold,
      ),
    );
  }
}
